aboutsummaryrefslogtreecommitdiff
path: root/src/addrman.h
diff options
context:
space:
mode:
authorAmiti Uttarwar <amiti@uttarwar.org>2023-02-19 10:09:28 -0700
committerAmiti Uttarwar <amiti@uttarwar.org>2023-03-17 17:59:02 -0700
commit26c3bf11e2487ed0ac578fb92619c148336003cb (patch)
tree9e54581d78cc858038a43e9218e5dbf347fa7b4e /src/addrman.h
parent48806412e2bcd023b78fc05f6c9ce092360d1db1 (diff)
downloadbitcoin-26c3bf11e2487ed0ac578fb92619c148336003cb.tar.xz
scripted-diff: rename local variables to match modern conventions
-BEGIN VERIFY SCRIPT- sed -i 's/fChanceFactor/chance_factor/g' src/addrman.cpp sed -i 's/nBucketPos/initial_position/g' src/addrman.cpp sed -i 's/nBucket/bucket/g' src/addrman.cpp src/addrman_impl.h sed -i 's/newOnly/new_only/g' src/addrman.cpp src/addrman_impl.h src/addrman.h src/test/addrman_tests.cpp -END VERIFY SCRIPT- Co-authored-by: Martin Zumsande <mzumsande@gmail.com>
Diffstat (limited to 'src/addrman.h')
-rw-r--r--src/addrman.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/addrman.h b/src/addrman.h
index 4985fc764c..374996e501 100644
--- a/src/addrman.h
+++ b/src/addrman.h
@@ -146,11 +146,11 @@ public:
/**
* Choose an address to connect to.
*
* @param[in] newOnly Whether to only select addresses from the new table.
* @return CAddress The record for the selected peer.
* seconds The last time we attempted to connect to that peer.
*/
- std::pair<CAddress, NodeSeconds> Select(bool newOnly = false) const;
+ std::pair<CAddress, NodeSeconds> Select(bool new_only = false) const;
/**
* Return all or many randomly selected addresses, optionally by network.
@@ -146,11 +146,11 @@ public:
* Choose an address to connect to.
*
- * @param[in] newOnly Whether to only select addresses from the new table.
+ * @param[in] new_only Whether to only select addresses from the new table.
* @return CAddress The record for the selected peer.
* seconds The last time we attempted to connect to that peer.